@@ -67,6 +67,7 @@ class CommandRunner(object):
         self._prompt_str_includes_rc = prompt_str_includes_rc
         self.match_id = None
         self.match = None
+        self.delay = 0
 
     def wait_for_prompt(self, timeout=-1):
         wait_for_prompt(self._connection, self._prompt_str, timeout)
@@ -93,7 +94,7 @@ class CommandRunner(object):
         self._connection.empty_buffer()
         if log_in_host is not None:
             self._connection.logfile = open(log_in_host, "a")
-        self._connection.sendline(cmd)
+        self._connection.sendline(cmd, delay=self.delay)
         start = time.time()
         if response is not None:
             self.match_id = self._connection.expect(response, timeout=timeout)
@@ -130,6 +131,17 @@ class CommandRunner(object):
 
         return rc
 
+    def get_wget_options(self):
+        patterns = ["GNU Wget", "BusyBox", pexpect.EOF, pexpect.TIMEOUT]
+        cmd = "LANG=C wget --help 2>&1 | head -n1"
+        self.run(cmd, patterns, timeout=10)
+        wget_options = ""
+        if self.match_id == 0:
+            wget_options = "--no-check-certificate --no-proxy --connect-timeout=30 -S --progress=dot -e dotbytes=2M"
+        elif self.match_id == 1:
+            wget_options = "--proxy off"
+        return wget_options
+
 
 class NetworkCommandRunner(CommandRunner):
     """A CommandRunner with some networking utility methods."""
@@ -385,7 +397,8 @@ class LavaClient(object):
         self.target_device.deploy_android(images, rootfstype,
                                           bootloadertype, target_type)
 
-    def deploy_linaro(self, hwpack, rootfs, image, dtb, rootfstype, bootloadertype, qemu_pflash=None):
+    def deploy_linaro(self, hwpack, rootfs, image, dtb, rootfstype, bootfstype,
+                      bootloadertype, qemu_pflash=None):
         if image is None:
             if hwpack is None or rootfs is None:
                 raise CriticalError(
@@ -397,22 +410,26 @@ class LavaClient(object):
 
         if image is None:
             self.target_device.deploy_linaro(hwpack, rootfs, dtb,
-                                             rootfstype, bootloadertype,
-                                             qemu_pflash=qemu_pflash)
+                                             rootfstype, bootfstype,
+                                             bootloadertype, qemu_pflash=qemu_pflash)
         else:
             self.target_device.deploy_linaro_prebuilt(image, dtb, rootfstype,
-                                                      bootloadertype,
+                                                      bootfstype, bootloadertype,
                                                       qemu_pflash=qemu_pflash)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs,
-                             nfsrootfs, bootloader, firmware, bl1, bl2, bl31,
+                             nfsrootfs, image, bootloader, firmware, bl0, bl1, bl2, bl31,
                              rootfstype, bootloadertype, target_type, qemu_pflash=None):
-        self.target_device.deploy_linaro_kernel(kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs, bootloader, firmware,
+        self.target_device.deploy_linaro_kernel(kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs, image, bootloader, firmware, bl0,
                                                 bl1, bl2, bl31, rootfstype, bootloadertype, target_type, qemu_pflash=qemu_pflash)
 
     def dummy_deploy(self, target_type):
         self.target_device.dummy_deploy(target_type)
 
+    def deploy_lxc_image(self, name, release, arch, target_type, persist):
+        self.target_device.deploy_lxc_image(name, release, arch, target_type,
+                                            persist)
+
     @contextlib.contextmanager
     def runner(self):
         """
