@@ -76,6 +76,7 @@ class DeviceSchema(schema.Schema):
     client_type = schema.StringOption()
     connection_command = schema.StringOption(fatal=True)
     connection_command_pattern = schema.StringOption(default="Connected\.\r")
+    connection_command_terminate = schema.StringOption(default=None)
     data_part_android = schema.IntOption()
     data_part_android_org = schema.IntOption()
     default_network_interface = schema.StringOption()
@@ -91,6 +92,7 @@ class DeviceSchema(schema.Schema):
     fvp_terminal_port_pattern = schema.StringOption(default="terminal_0: Listening for serial connection on port (\d+)")
     bootloader_serial_delay_ms = schema.IntOption(default=0)
     test_shell_serial_delay_ms = schema.IntOption(default=0)
+    master_image_serial_delay_ms = schema.IntOption(default=0)
     lmc_dev_arg = schema.StringOption()
     master_str = schema.StringOption(default="root@master")
     pre_connect_command = schema.StringOption()
@@ -216,6 +218,7 @@ class DeviceSchema(schema.Schema):
     simulator_version_command = schema.StringOption()
     simulator_command = schema.StringOption()
     simulator_command_flag = schema.StringOption(default=" -C ")
+    simulator_options = schema.ListOption(default=None)
     simulator_axf_files = schema.ListOption()
     simulator_kernel_files = schema.ListOption(default=None)
     simulator_kernel = schema.StringOption(default=None)
@@ -242,6 +245,7 @@ class DeviceSchema(schema.Schema):
     dummy_ssh_port = schema.IntOption(default=22)
     dummy_ssh_username = schema.StringOption(default='root')
     dummy_ssh_identity_file = schema.StringOption(default=None)
+    dummy_lxc_container = schema.StringOption(default="default")
 
     # for qemu devices
     qemu_binary = schema.StringOption(default="qemu-system-arm")
@@ -297,16 +301,20 @@ class DeviceSchema(schema.Schema):
     # for vexpress devices
     vexpress_uefi_default = schema.StringOption(default=None)
     vexpress_bl1_default = schema.StringOption(default=None)
+    vexpress_bl0_default = schema.StringOption(default=None)
     vexpress_uefi_path = schema.StringOption(default=None)
     vexpress_uefi_image_files = schema.ListOption(default=None)
     vexpress_uefi_image_filename = schema.StringOption(default="fip.bin")
     vexpress_uefi_backup_path = schema.StringOption(default=None)
+    vexpress_bl0_path = schema.StringOption(default=None)
+    vexpress_bl0_backup_path = schema.StringOption(default=None)
     vexpress_bl1_path = schema.StringOption(default=None)
     vexpress_bl1_image_files = schema.ListOption(default=None)
     vexpress_bl1_image_filename = schema.StringOption(default="bl1.bin")
     vexpress_bl1_backup_path = schema.StringOption(default=None)
     vexpress_stop_autoboot_prompt = schema.StringOption(default='Press Enter to stop auto boot...')
     vexpress_usb_mass_storage_device = schema.StringOption(default=None)
+    vexpress_requires_bl0 = schema.BoolOption(default=False)
     vexpress_requires_trusted_firmware = schema.BoolOption(default=False)
     bridged_networking = schema.BoolOption(default=False)
     bridge_interface = schema.StringOption(default="br0")
@@ -317,6 +325,9 @@ class DeviceSchema(schema.Schema):
     vexpress_flash_range_low = schema.StringOption(default=None)
     vexpress_flash_range_high = schema.StringOption(default=None)
 
+    # for lxc devices
+    lxc_driver = schema.StringOption(default=None)
+
 
 class OptionDescriptor(object):
     def __init__(self, name):
