@@ -185,8 +185,8 @@ class BaseDriver(object):
         finalize_process(proc)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
-                             bootloader, firmware, bl1, bl2, bl31, rootfstype,
-                             bootloadertype, target_type, scratch_dir,
+                             image, bootloader, firmware, bl0, bl1, bl2, bl31,
+                             rootfstype, bootloadertype, target_type, scratch_dir,
                              qemu_pflash=None):
         self.target_type = target_type
         self.scratch_dir = scratch_dir
@@ -345,8 +345,8 @@ class fastboot(BaseDriver):
         super(fastboot, self).__init__(device)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
-                             bootloader, firmware, bl1, bl2, bl31, rootfstype,
-                             bootloadertype, target_type, scratch_dir,
+                             image, bootloader, firmware, bl0, bl1, bl2, bl31,
+                             rootfstype, bootloadertype, target_type, scratch_dir,
                              qemu_pflash=None):
         raise CriticalError('This platform does not support kernel deployment!')
 
@@ -368,7 +368,7 @@ class nexus10(fastboot):
         super(nexus10, self).__init__(device)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
-                             bootloader, firmware, bl1, bl2, bl31, rootfstype,
+                             image, bootloader, firmware, bl0, bl1, bl2, bl31, rootfstype,
                              bootloadertype, target_type, scratch_dir, qemu_pflash=None):
         raise CriticalError('This platform does not support kernel deployment!')
 
@@ -383,8 +383,8 @@ class tshark(fastboot):
         super(tshark, self).__init__(device)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
-                             bootloader, firmware, bl1, bl2, bl31, rootfstype, bootloadertype,
-                             target_type, scratch_dir, qemu_pflash=None):
+                             image, bootloader, firmware, bl0, bl1, bl2, bl31, rootfstype,
+                             bootloadertype, target_type, scratch_dir, qemu_pflash=None):
         raise CriticalError('This platform does not support kernel deployment!')
 
     def boot(self, boot_cmds=None):
@@ -454,8 +454,8 @@ class capri(fastboot_serial):
         super(capri, self).__init__(device)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
-                             bootloader, firmware, bl1, bl2, bl31, rootfstype, bootloadertype,
-                             target_type, scratch_dir, qemu_pflash=None):
+                             image, bootloader, firmware, bl0, bl1, bl2, bl31, rootfstype,
+                             bootloadertype, target_type, scratch_dir, qemu_pflash=None):
         raise CriticalError('This platform does not support kernel deployment!')
 
     def erase_boot(self):
@@ -494,8 +494,8 @@ class pxa1928dkb(fastboot_serial):
         super(pxa1928dkb, self).__init__(device)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
-                             bootloader, firmware, bl1, bl2, bl31, rootfstype, bootloadertype,
-                             target_type, scratch_dir, qemu_pflash=None):
+                             image, bootloader, firmware, bl0, bl1, bl2, bl31, rootfstype,
+                             bootloadertype, target_type, scratch_dir, qemu_pflash=None):
         raise CriticalError('This platform does not support kernel deployment!')
 
     def connect(self):
@@ -520,8 +520,8 @@ class k3v2(fastboot_serial):
         super(k3v2, self).__init__(device)
 
     def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
-                             bootloader, firmware, bl1, bl2, bl31, rootfstype, bootloadertype,
-                             target_type, scratch_dir, qemu_pflash=None):
+                             image, bootloader, firmware, bl0, bl1, bl2, bl31, rootfstype,
+                             bootloadertype, target_type, scratch_dir, qemu_pflash=None):
         raise CriticalError('This platform does not support kernel deployment!')
 
     def enter_fastboot(self):
