@@ -208,18 +208,20 @@ class Target(object):
         """
         raise NotImplementedError('power_on')
 
-    def deploy_linaro(self, hwpack, rfs, dtb, rootfstype, bootloadertype, qemu_pflash=None):
+    def deploy_linaro(self, hwpack, rfs, dtb, rootfstype, bootfstype,
+                      bootloadertype, qemu_pflash=None):
         raise NotImplementedError('deploy_image')
 
     def deploy_android(self, images, rootfstype,
                        bootloadertype, target_type):
         raise NotImplementedError('deploy_android_image')
 
-    def deploy_linaro_prebuilt(self, image, dtb, rootfstype, bootloadertype, qemu_pflash=None):
+    def deploy_linaro_prebuilt(self, image, dtb, rootfstype, bootfstype,
+                               bootloadertype, qemu_pflash=None):
         raise NotImplementedError('deploy_linaro_prebuilt')
 
-    def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs, bootloader, firmware, bl1, bl2,
-                             bl31, rootfstype, bootloadertype, target_type, qemu_pflash=None):
+    def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs, image, bootloader, firmware, bl0, bl1,
+                             bl2, bl31, rootfstype, bootloadertype, target_type, qemu_pflash=None):
         raise NotImplementedError('deploy_linaro_kernel')
 
     def dummy_deploy(self, target_type):
@@ -321,8 +323,10 @@ class Target(object):
 
     def _find_dir(self, rootdir, pattern):
         dest = None
-        for root, dirs, files in os.walk(rootdir, topdown=False):
+        for root, dirs, files in os.walk(str(rootdir), topdown=False):
             for dir_name in dirs:
+                dir_name = str(dir_name)
+                root = str(root)
                 if re.match(pattern, dir_name):
                     dest = os.path.join(root, dir_name)
                     return dest
@@ -719,16 +723,12 @@ class Target(object):
         else:
             raise RuntimeError('bad file extension: %s' % tar_url)
 
-        if busybox:
-            wget_options = '--proxy off'
-        else:
-            wget_options = '--no-check-certificate --no-proxy --connect-timeout=30 -S --progress=dot -e dotbytes=2M'
+        wget_options = runner.get_wget_options()
 
         if self._image_has_selinux_support(runner, 3):
             self.context.selinux = '--selinux'
         else:
             self.context.selinux = ''
-
         runner.run('wget %s -O - %s %s | /bin/tar %s -C %s -xmf -'
                    % (wget_options, tar_url, decompression_cmd, self.context.selinux, dest),
                    timeout=timeout)
