@@ -129,6 +129,7 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
         if self.parent:  # action
             self.children[self] = self.actions
             self.parent.pipeline = self
+            action.section = self.parent.section
         else:
             action.level = "%s" % (len(self.actions))
         # create a log handler just for this action.
@@ -251,7 +252,7 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
         # Diagnosis is not allowed to alter the connection, do not use the return value.
         return None
 
-    def run_actions(self, connection, args=None):  # pylint: disable=too-many-branches,too-many-statements
+    def run_actions(self, connection, args=None):  # pylint: disable=too-many-branches,too-many-statements,too-many-locals
 
         def cancelling_handler(*args):  # pylint: disable=unused-argument
             """
@@ -275,7 +276,9 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
                 if final.name == "finalize":
                     final.run(connection, None)
                 else:
-                    raise RuntimeError("Invalid job pipeline - no finalize action to run after job timeout.")
+                    msg = "Invalid job pipeline - no finalize action to run after job timeout."
+                    action.logger.error(msg)
+                    raise RuntimeError(msg)
                 raise JobError(msg)
 
             # Begin the action
@@ -287,7 +290,7 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
             msg = {'msg': 'start: %s %s (max %ds)' % (action.level,
                                                       action.name,
                                                       action.timeout.duration),
-                   'ts': datetime.datetime.utcnow()}
+                   'ts': datetime.datetime.utcnow().isoformat()}
             if self.parent is None:
                 action.logger.info(msg)
             else:
@@ -297,6 +300,7 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
                     signal.signal(signal.SIGINT, cancelling_handler)
                     signal.signal(signal.SIGTERM, cancelling_handler)
                 start = time.time()
+                new_connection = None
                 try:
                     # FIXME: not sure to understand why we have two cases here?
                     if not connection:
@@ -304,20 +308,36 @@ class Pipeline(object):  # pylint: disable=too-many-instance-attributes
                             new_connection = action.run(connection, args)
                     else:
                         new_connection = action.run(connection, args)
-                except (ValueError, KeyError, TypeError, RuntimeError) as exc:
-                    action.logger.exception(exc)
+                # overly broad exceptions will cause issues with RetryActions
+                # always ensure the unit tests continue to pass with changes here.
+                except (ValueError, KeyError, TypeError, RuntimeError, AttributeError) as exc:
+                    exc_type, exc_value, exc_traceback = sys.exc_info()
+                    traceback_details = {
+                        'filename': exc_traceback.tb_frame.f_code.co_filename,
+                        'lineno': exc_traceback.tb_lineno,
+                        'name': exc_traceback.tb_frame.f_code.co_name,
+                        'type': exc_type.__name__,
+                        'message': exc_value.message,
+                    }
+                    action.logger.exception(traceback_details)
                     raise RuntimeError(exc)
+                except KeyboardInterrupt:
+                    raise KeyboardInterrupt
                 action.elapsed_time = time.time() - start
                 # Add action end timestamp to the log message
                 msg = {'msg': "%s duration: %.02f" % (action.name,
                                                       action.elapsed_time),
-                       'ts': datetime.datetime.utcnow()}
+                       'ts': datetime.datetime.utcnow().isoformat()}
                 if self.parent is None:
                     action.logger.info(msg)
                 else:
                     action.logger.debug(msg)
                 if action.results and isinstance(action.logger, YAMLLogger):
-                    action.logger.results(action.results)
+                    action.results.update({'level': action.level,
+                                           'duration': action.elapsed_time,
+                                           'timeout': action.timeout.duration,
+                                           })
+                    action.logger.results({action.name: action.results})
                 if new_connection:
                     connection = new_connection
             except KeyboardInterrupt:
@@ -369,6 +389,7 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
         self.max_retries = 1  # unless the strategy or the job parameters change this, do not retry
         self.diagnostics = []
         self.protocols = []  # list of protocol objects supported by this action, full list in job.protocols
+        self.section = None
 
     # public actions (i.e. those who can be referenced from a job file) must
     # declare a 'class-type' name so they can be looked up.
@@ -533,6 +554,9 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
         if ' ' in self.name:
             self.errors = "Whitespace must not be used in action names, only descriptions or summaries: %s" % self.name
 
+        if not self.section:
+            self.errors = "%s action has no section set" % self
+
         # Collect errors from internal pipeline actions
         self.job.context.setdefault(self.name, {})
         if self.internal_pipeline:
@@ -557,6 +581,7 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
         Includes default support for proxy settings in the environment.
         Blocks until the command returns then processes & logs the output.
         """
+        # FIXME: add option to only check stdout or stderr for failure output
         if type(command_list) != list:
             raise RuntimeError("commands to run_command need to be a list")
         log = None
@@ -664,6 +689,17 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
                 data['url'] = self.url.geturl()  # pylint: disable=no-member
             elif attr == 'vcs':
                 data[attr] = getattr(self, attr).url
+            elif attr == 'protocols':
+                data['protocols'] = {}
+                for protocol in getattr(self, attr):
+                    data['protocols'][protocol.name] = {}
+                    protocol_attrs = set([attr for attr in dir(protocol)
+                                          if not attr.startswith('_') and getattr(protocol, attr)
+                                          and not isinstance(getattr(protocol, attr), types.MethodType)
+                                          and not isinstance(getattr(protocol, attr), InternalObject)])
+                    for protocol_attr in protocol_attrs:
+                        if protocol_attr not in ['logger']:
+                            data['protocols'][protocol.name][protocol_attr] = getattr(protocol, protocol_attr)
             else:
                 data[attr] = getattr(self, attr)
         if 'deployment_data' in self.parameters:
@@ -696,6 +732,9 @@ class Action(object):  # pylint: disable=too-many-instance-attributes
     def wait(self, connection):
         if not connection:
             return
+        if not connection.connected:
+            self.logger.debug("Already disconnected")
+            return
         self.logger.debug("%s: Wait for prompt. %s seconds" % (self.name, int(self.timeout.duration)))
         connection.wait()
 
