@@ -39,6 +39,7 @@ class BootKExec(Boot):
     def __init__(self, parent, parameters):
         super(BootKExec, self).__init__(parent)
         self.action = BootKexecAction()
+        self.action.section = self.action_type
         self.action.job = self.job
         parent.add_action(self.action, parameters)
 
@@ -87,7 +88,7 @@ class KexecAction(Action):
     def validate(self):
         super(KexecAction, self).validate()
         self.command = self.parameters.get('command', '/sbin/kexec')
-        self.load_command = self.command
+        self.load_command = self.command[:]  # local copy for idempotency
         self.command += ' -e'
         if 'kernel' in self.parameters:
             self.load_command += ' --load %s' % self.parameters['kernel']
