@@ -18,23 +18,20 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-import sys
 import os
 import time
-from StringIO import StringIO
 import unittest
+import simplejson
 import yaml
 
-from lava_dispatcher.pipeline import Pipeline, Action
+from lava_dispatcher.pipeline.utils.filesystem import mkdtemp
+from lava_dispatcher.pipeline.action import Pipeline, Action
 from lava_dispatcher.pipeline.parser import JobParser
 from lava_dispatcher.pipeline.job import Job
-from lava_dispatcher.tests.helper import create_device_config, create_config
-from lava_dispatcher.config import get_config
-from lava_dispatcher.context import LavaContext
-from lava_dispatcher.device.qemu import QEMUTarget
+from lava_dispatcher.pipeline.device import NewDevice
 
 
-class TestAction(unittest.TestCase):
+class TestAction(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
     def test_references_a_device(self):
         device = object()
@@ -43,79 +40,64 @@ class TestAction(unittest.TestCase):
         self.assertIs(cmd.device, device)
 
 
-class TestPipelineInit(unittest.TestCase):
+class TestPipelineInit(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
-    class FakeAction(Action):
+    class FakeAction(Action):  # pylint: disable=abstract-class-not-used
 
         def __init__(self):
             self.ran = False
-            super(FakeAction, self).__init__(None)
+            super(TestPipelineInit.FakeAction, self).__init__()
 
         def run(self, connection, args=None):
             self.ran = True
 
+        def post_process(self):
+            raise NotImplementedError("invalid")
+
     def setUp(self):
         self.sub0 = TestPipelineInit.FakeAction()
         self.sub1 = TestPipelineInit.FakeAction()
 
+    def test_pipeline_init(self):
+        self.assertIsNotNone(self.sub0)
+        self.assertIsNotNone(self.sub1)
 
-class TestJobParser(unittest.TestCase):
+
+class TestJobParser(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
     def setUp(self):
         factory = Factory()
-        self.job = factory.create_job('sample_jobs/basics.yaml')
+        self.job = factory.create_kvm_job('sample_jobs/basics.yaml', mkdtemp())
 
-    def test_parser_creates_a_job_with_a_pipeline(self):
+    def test_parser_creates_a_job_with_a_pipeline(self):  # pylint: disable=invalid-name
+        if not self.job:
+            return unittest.skip("not all deployments have been implemented")
         self.assertIsInstance(self.job, Job)
         self.assertIsInstance(self.job.pipeline, Pipeline)
 
-    def test_pipeline_gets_multiple_actions_in_it(self):
+    def test_pipeline_gets_multiple_actions_in_it(self):  # pylint: disable=invalid-name
+        if not self.job:
+            return unittest.skip("not all deployments have been implemented")
         self.assertTrue(self.job.actions > 1)
 
-# FIXME: disabled as the current parser relies on a real file, not a string.
-# class TestJobSnippet(unittest.TestCase):
 
-#    def setUp(self):
-#        factory = Factory()
-#        fake_qemu = os.path.join(os.path.dirname(__file__), '..', '..', 'tests', 'test-config', 'bin', 'fake-qemu')
-#        device = factory.create_kvm_target({'qemu-binary': fake_qemu})
-#        self.parser = JobParser()
-#        self.job = self.parser.parse(self.boot_from_sata, device)
-
-#    def boot_from_sata(self):
-#        return StringIO({
-#            'actions': [
-#                {'deploy': {'to': 'sata', 'image': 'file:///path/to/image.img'}},
-#            ]
-#        })
-
-#    def test_boot_from_sata(self):
-#        self.assertEquals(1, len(self.job.actions))
-#        self.assertEquals(self.job.actions[self.job.pipeline][0].level, "1")
-
-#    def test_action_data(self):
-#        deploy_action = self.job.actions[self.job.pipeline][0]
-#        self.assertEqual(type(deploy_action), DeployAction)
-#        self.assertEquals('sata', deploy_action.parameters['to'])
-#        self.assertEquals('file:///path/to/image.img', deploy_action.parameters['image'])
-
-#    def test_action_class(self):
-#        job = self.parser.parse(self.boot_from_sata)
-#        deploy_action = job.actions[job.pipeline][0]
-#
-#        self.assertIsInstance(deploy_action, DeployAction)
+def pipeline_reference(filename):
+    with open(os.path.join(os.path.dirname(__file__),
+              'pipeline_refs', filename), 'r') as f_ref:
+        return yaml.load(f_ref)
 
 
-class TestValidation(unittest.TestCase):
+class TestValidation(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
-    def test_action_is_valid_if_there_are_not_errors(self):
+    def test_action_is_valid_if_there_are_not_errors(self):  # pylint: disable=invalid-name
         action = Action()
         action.__errors__ = [1]
         self.assertFalse(action.valid)
         action.__errors__ = []
         self.assertTrue(action.valid)
 
-    def test_composite_action_aggregates_errors_from_sub_actions(self):
+    def test_composite_action_aggregates_errors_from_sub_actions(self):  # pylint: disable=invalid-name
+        # Unable to call Action.validate() as there is no job in this unit test
         sub1 = Action()
         sub1.__errors__ = [1]
         sub2 = Action()
@@ -123,11 +105,9 @@ class TestValidation(unittest.TestCase):
         sub2.__errors__ = [2]
 
         pipe = Pipeline()
-        self.assertRaises(RuntimeError, pipe.add_action, sub1)
         sub1.name = "sub1"
         pipe.add_action(sub1)
         pipe.add_action(sub2)
-
         self.assertEqual([1, 2], pipe.errors)
 
 
@@ -137,41 +117,32 @@ class Factory(object):
     Factory objects are dispatcher based classes, independent
     of any database objects.
     """
-    def create_kvm_target(self, extra_device_config=None):
-        if not extra_device_config:
-            extra_device_config = {}
-        create_config('lava-dispatcher.conf', {})
-
-        device_config_data = {'device_type': 'kvm'}
-        device_config_data.update(extra_device_config)
-        device_config = create_device_config('fakekvm', device_config_data)  # use a device name unlikely to exist
-
-        dispatcher_config = get_config()
-
-        context = LavaContext('fakekvm', dispatcher_config, None, None, None)
-        return QEMUTarget(context, device_config)
-
-    def create_fake_qemu_job(self):
-        factory = Factory()
-        fake_qemu = os.path.join(os.path.dirname(__file__), '..', '..', 'tests', 'test-config', 'bin', 'fake-qemu')
-        device = factory.create_kvm_target({'qemu-binary': fake_qemu})
+    def create_fake_qemu_job(self, output_dir=None):  # pylint: disable=no-self-use
+        device = NewDevice(os.path.join(os.path.dirname(__file__), '../devices/kvm01.yaml'))
         sample_job_file = os.path.join(os.path.dirname(__file__), 'sample_jobs/basics.yaml')
-        self.sample_job_data = open(sample_job_file)
-        self.parser = JobParser()
-        job = self.parser.parse(self.sample_job_data, device)
+        parser = JobParser()
+        try:
+            with open(sample_job_file) as sample_job_data:
+                job = parser.parse(sample_job_data, device, 4212, None, output_dir=output_dir)
+        except NotImplementedError:
+            # some deployments listed in basics.yaml are not implemented yet
+            return None
         return job
 
-    def create_job(self, filename, output_dir=None):
-        device = self.create_kvm_target()
+    def create_kvm_job(self, filename, output_dir='/tmp/'):  # pylint: disable=no-self-use
+        device = NewDevice(os.path.join(os.path.dirname(__file__), '../devices/kvm01.yaml'))
         kvm_yaml = os.path.join(os.path.dirname(__file__), filename)
-        self.sample_job_data = open(kvm_yaml)
-        self.parser = JobParser()
-        job = self.parser.parse(self.sample_job_data, device, output_dir=output_dir)
-        job.context = LavaContext(device.config.hostname, get_config(), sys.stderr, job.parameters, '/tmp')
+        parser = JobParser()
+        try:
+            with open(kvm_yaml) as sample_job_data:
+                job = parser.parse(sample_job_data, device, 4212, None, output_dir=output_dir)
+        except NotImplementedError:
+            # some deployments listed in basics.yaml are not implemented yet
+            return None
         return job
 
 
-class TestPipeline(unittest.TestCase):
+class TestPipeline(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
     class FakeAction(Action):
 
@@ -209,7 +180,7 @@ class TestPipeline(unittest.TestCase):
         self.assertEqual(action.level, "1")
         try:
             simplejson.loads(pipe.describe())
-        except:
+        except:  # pylint: disable=bare-except
             self.assertFalse(0)
 
     def test_create_internal_pipeline(self):
@@ -240,7 +211,7 @@ class TestPipeline(unittest.TestCase):
         self.assertEqual(len(retry_pipe.children[retry_pipe]), 1)
         self.assertEqual(action.level, "2.1")
 
-    def test_complex_pipeline(self):
+    def test_complex_pipeline(self):  # pylint: disable=too-many-statements
         action = Action()
         action.name = "starter_action"
         action.description = "test action only"
@@ -294,16 +265,48 @@ class TestPipeline(unittest.TestCase):
         action.summary = "action"
         pipe.add_action(action)
         self.assertEqual(action.level, "3")
-        self.assertEqual(len(pipe.describe().values()), 8)
+        self.assertEqual(len(pipe.describe()), 3)
 
     def test_simulated_action(self):
         factory = Factory()
-        job = factory.create_job('sample_jobs/basics.yaml')
-        # uncomment to see the YAML dump of the pipeline.
-        # print yaml.dump(job.pipeline.describe())
+        job = factory.create_kvm_job('sample_jobs/basics.yaml', mkdtemp())
+        if not job:
+            return unittest.skip("not all deployments have been implemented")
+        self.assertIsNotNone(job)
+
+    def test_describe(self):
+        factory = Factory()
+        job = factory.create_kvm_job('sample_jobs/kvm.yaml', mkdtemp())
+        self.assertIsNotNone(job)
+        pipe = job.pipeline.describe()
+        for item in pipe:
+            self.assertNotIn('match', item)
+            if 'pipeline' in item:
+                for element in item['pipeline']:
+                    self.assertNotIn('match', element)
 
 
-class TestFakeActions(unittest.TestCase):
+class TestFakeActions(unittest.TestCase):  # pylint: disable=too-many-public-methods
+
+    class KeepConnection(Action):  # pylint: disable=abstract-class-not-used
+        def __init__(self):
+            super(TestFakeActions.KeepConnection, self).__init__()
+            self.name = "keep-connection"
+
+        def run(self, connection, args=None):
+            pass
+
+        def post_process(self):
+            raise NotImplementedError("invalid")
+
+    class MakeNewConnection(Action):
+        def __init__(self):
+            super(TestFakeActions.MakeNewConnection, self).__init__()
+            self.name = "make-new-connection"
+
+        def run(self, connection, args=None):
+            new_connection = object()
+            return new_connection
 
     def setUp(self):
         self.sub0 = TestPipeline.FakeAction()
@@ -326,66 +329,16 @@ class TestFakeActions(unittest.TestCase):
         self.assertNotEqual(self.sub0.elapsed_time, 0)
         self.assertNotEqual(self.sub1.elapsed_time, 0)
 
-    def test_prepare(self):
-        class PrepareAction(Action):
-
-            def __init__(self, pipeline):
-                self.called = False
-                super(PrepareAction, self).__init__()
-                self.name = "prepare"
-
-            def prepare(self):
-                self.called = True
-
-        pipe = Pipeline()
-        prepare = PrepareAction(pipe)
-        pipe.add_action(prepare)
-        pipe.prepare_actions()
-        self.assertTrue(prepare.called)
-
-    def test_post_process(self):
-
-        class PostProcess(Action):
-
-            def __init__(self, pipeline):
-                self.called = False
-                super(PostProcess, self).__init__()
-                self.name = "post-process"
-
-            def post_process(self):
-                self.called = True
-
-        pipe = Pipeline()
-        post_process = PostProcess(pipe)
-        pipe.add_action(post_process)
-        pipe.post_process_actions()
-        self.assertTrue(post_process.called)
-
     def test_keep_connection(self):
-        class KeepConnection(Action):
-            def __init__(self):
-                super(KeepConnection, self).__init__()
-                self.name = "keep-connection"
-
-            def run(self, connection, args=None):
-                pass
 
         pipe = Pipeline()
-        pipe.add_action(KeepConnection())
+        pipe.add_action(TestFakeActions.KeepConnection())
         conn = object()
         self.assertIs(conn, pipe.run_actions(conn))
 
     def test_change_connection(self):
-        class MakeNewConnection(Action):
-            def __init__(self):
-                super(MakeNewConnection, self).__init__()
-                self.name = "make-new-connection"
-
-            def run(self, connection, args=None):
-                new_connection = object()
-                return new_connection
 
         pipe = Pipeline()
-        pipe.add_action(MakeNewConnection())
+        pipe.add_action(TestFakeActions.MakeNewConnection())
         conn = object()
         self.assertIsNot(conn, pipe.run_actions(conn))
